# sco507.sh
# Courtesy of J. Kean Johnston <jkj@sco.com>
###############################################################
#
# To use cc,  use   sh Configure
# To use gcc, use   sh Configure -Dcc=gcc.
#
# NOTE Only gcc 2.95.3 is supported.
#
###############################################################

case `/bin/uname -X | egrep '3\.2v'` in
*3.2v5.0.[6789]*) scorls=507 ;;   # OSR 5.0.7 or later
*3.2v5.1.*)	  scorls=510 ;;   # OSR 5.1.0 or later
*)
   echo "************************************************************" >&4
   echo "" >&4
   echo "  sco507.sh hints file only supports:" >&4
   echo "" >&4
   echo "    - SCO OpenServer Release 5.0.7 or later" >&4
   echo "" >&4
   echo "***********************************************************" >&4
   exit
;;
esac

###############################################################
# Common fixes for all compilers an releases:

###############################################################
# What is true for SCO5 is true for SCO3 too today, so let's have a single
# symbol for both
ccflags="-DPERL_SCO -DPERL_SCO507"

###############################################################
# Compilers options section:
    
###############################################################
# Need this in release 5 because of changed fpu exeption rules
ccflags="$ccflags -D HAS_FPSETMASK"

case "$cc" in
    *gcc*)
        optimize='-O6 -fomit-frame-pointer -fexpensive-optimizations'
    ;;
    *)
        ccflags="$ccflags -belf"
        optimize='-O'
    ;;
esac

###############################################################
# Dynamic loading section:
#
# We use the compiler driver to create shared objects so that it drives
# the link editor correctly, and so that it picks up the right choice of
# CRT files and libraries.
#
# ccdlflags : must tell the linker to export all global symbols
# cccdlflags: must tell the compiler to generate relocatable code
# lddlflags : must tell the linker to output a shared library
#
# /usr/gnu/lib is added for convenience, as thats where the officially
# supported library extensions go. If the user wants to search in
# /usr/local/lib let them specify that themselves.
if test "$usedl" != "n"; then
    ld=$cc
    case "$cc" in
        *gcc*)
            ccdlflags='-Wl,-Bexport'
            cccdlflags='-fpic'
            lddlflags='-shared'
        ;;
        *)
            ccdlflags='-Bexport -L/usr/gnu/lib'
            cccdlflags='-Kpic'
            lddlflags='-G -L/usr/gnu/lib'
        ;;
    esac

    ###############################################################
    # Use dynamic loading
    usedl='define'
    dlext='so'
    dlsrc='dl_dlopen.xs'

    ###############################################################
    # Force to define those symbols, as they are #defines and not
    # catched by Configure, and they are useful
    d_dlopen='define'
    d_dlerror='define'
fi

###############################################################
# Various hints, common to all releases, to have it work better:

###############################################################
# We need to remove libdl, as libdl.so exists, but ld complains
# it can't find libdl.a ! Bug or feature ? :-)
libswanted=`echo " $libswanted " | sed -e 's/ dl / /'`
set X $libswanted
shift
libswanted="$*"

###############################################################
# Remove libbind because it conflicts with libsocket.
libswanted=`echo " $libswanted " | sed -e 's/ bind / /'`
set X $libswanted
shift
libswanted="$*"

###############################################################
# ODBM does actually work you just have to know how to bludgeon it :)
i_dbm='define'

###############################################################
# We don't want Xenix cross-development libraries
glibpth=`echo $glibpth | sed -e 's! /usr/lib/386 ! !' -e 's! /lib/386 ! !'`
xlibpth=''

###############################################################
# Using nm is usually a bad idea. It precludes the compiler from getting
# the opportunity to map symbols based on include files. Don't use it.
case "$usenm" in
'') usenm='false' ;;
esac

###############################################################
# If you want to use nm, you'll probably have to use nm -p.  The
# following does that for you:
nm_opt='-p'

###############################################################
# Perl 5.003_05 and later try to include both <time.h> and <sys/select.h>
# in pp_sys.c, but that fails due to a redefinition of struct timeval.
# This will generate a WHOA THERE.  Accept the default.
#i_sysselct=$undef

###############################################################
#END of hint file
